const seq = (s, e, step) => {
    const lst = [];
    do {
        lst.push(s);
        s += step;
    } while (s < e);
    lst.push(e);
    return lst;
};
const gen = (field) => {
    switch (field.kind) {
        case "number":
            return curr => curr === field.value;
        case "range":
            const [l, r] = field.value;
            return curr => l <= curr && r >= curr;
        case "step":
            const [range, ss] = field.value;
            const [ll, rr] = range.value;
            const step = seq(ll, rr, ss);
            return curr => step.includes(curr);
        case "list":
            const list = field.value;
            const fns = list.map(x => gen(x));
            return curr => fns.some(fn => fn(curr));
    }
};
const converter = (cron) => {
    const v = {
        minute: gen(cron.minute),
        hour: gen(cron.hour),
        date: gen(cron.date),
        month: gen(cron.month),
        week: gen(cron.week),
    };
    return ({ minute, hour, date, month, week }) => {
        return (v.minute(minute) &&
            v.hour(hour) &&
            v.date(date) &&
            v.month(month) &&
            v.week(week));
    };
};
export default converter;
